local vexalarm_profiles_profile_load = ""
local vexalarm_profiles_profile_delete = ""
local vexalarm_profiles_profile_new = GetRealmName().." "..select(1, UnitName("player"))

function vexalarm.panel_profiles()
	return {
		type = "group",
		args = {
			grpex = {
				name = "Information",
				order=1, type = "group", dialogInline = true,
				args = {
					info1={name = "You can save your current settings in profiles and load them later on. That way you can easily copy your settings to other characters.", type="description", order=2, fontSize="medium"},
					space1={name= " ", type="description", order=10},
					},
				},
			frame_space1 = {name =" ", type = "description", order=2},
			grpadd = {
				name = "Add Profile",
				order=3, type ="group", dialogInline = true,
				args = {
					profile_new = {
						name = "Name",
						desc = "Enter a name for the new profile",
						order=1, type = "input", multiline = false, width = "double",
						validate = function (info, val)
							if vexalarm_profile_checkName(val) then return true
							else return "ERROR - "..val.." is not a valid name" end
							end,
						set = function(info,val) vexalarm_profiles_profile_new = val end,
						get = function() return vexalarm_profiles_profile_new end,
						},
					profile_new_add = {
						name = "add", width="half",
						order=2, type = "execute",
						func = function(info,val) vexalarm_profile_add() end,
						},
					grpadddelete_allowed = {name ="Profile names may only contain numbers, letters and spaces", type = "description", order=3, fontSize="medium"},
					},
				},
			frame_space2 = {name =" ", type = "description", order=4},
			grpdelete = {
				name = "Delete Profile",
				order=5, type ="group", dialogInline = true,
				args = {
					profile_delete = {
						name = "Profile",
						order=1, type = "select", style = "dropdown",
						desc = "Delete an existing profile",
						values = vexalarm_profiles["profilelist"],
						set = function(self,key) vexalarm_profiles_profile_delete = key end,
						get = function() return vexalarm_profiles_profile_delete end,
						},
					delete_exe = {
						name = "delete",
						order=2, type = "execute",
						func = function(info,val) vexalarm_profile_delete() end,
						confirm = true,
						confirmText = "Are you sure you want to delete the profile?"
						},
					},
				},
			frame_space3 = {name =" ", type = "description", order=6},
			grpload = {
				name = "Load Profile",
				order=7, type ="group", dialogInline = true,
				args = {
					profile_load = {
						name = "Profile",
						order=1, type = "select", style = "dropdown",
						values = vexalarm_profiles["profilelist"],
						set = function(self,key) vexalarm_profiles_profile_load = key end,
						get = function() return vexalarm_profiles_profile_load end,
						},
					load_space = {name =" ", type = "description", order=2},
					load_exe_all = {
						name = "load complete profile",
						desc = "load settings, spell-adjustments and spell-profiles",
						order=3, type = "execute", width="double",
						func = function(info,val) vexalarm_profile_load("all") vexalarm_initialize(true) end,
						},
					load_space2 = {name =" ", type = "description", order=4},
					load_exe_settings = {
						name = "load settings",
						order=5, type = "execute",
						func = function(info,val) vexalarm_profile_load("parameters") vexalarm_initialize(true) end,
						},
					load_exe_spells = {
						name = "load spell-settings",
						desc = "spell-settings are the current spell adjustments of that profile",
						order=6, type = "execute",
						func = function(info,val) vexalarm_profile_load("spells") vexalarm_initialize(true) end,
						},
					load_exe_spellprofiles = {
						name = "load spell-profiles",
						order=7, type = "execute",
						func = function(info,val) vexalarm_profile_load("spellprofiles") vexalarm_initialize(true) end,
						},
					},
				},
			}
		}
end

function vexalarm_profile_add()
	local key = vexalarm_profiles_profile_new
	if key ~= "" then
		vexalarm_profiles["profilelist"][key] = key
		
		if vexalarm_profiles[key] == nil then vexalarm_profiles[key] = {} end
		
		if vexalarm_profiles[key]["vexalarm_parameters"] == nil then vexalarm_profiles[key]["vexalarm_parameters"] = {} end
		vexalarm_profiles[key]["vexalarm_parameters"] = vexalarm_CopyTable(vexalarm_parameters)
		
		if vexalarm_profiles[key]["vexalarm_spellprofiles"] == nil then vexalarm_profiles[key]["vexalarm_spellprofiles"] = {} end
		vexalarm_profiles[key]["vexalarm_spellprofiles"] = vexalarm_CopyTable(vexalarm_spellprofiles)
		
		if vexalarm_profiles[key]["vexalarm_spells"] == nil then vexalarm_profiles[key]["vexalarm_spells"] = {} end
		vexalarm_profiles[key]["vexalarm_spells"] = vexalarm_CopyTable(vexalarm_spells)
		
		vexalarm_profiles_profile_new = ""
	end
end

function vexalarm_profile_delete(key)
	if key == nil then key = vexalarm_profiles_profile_delete end
	if key ~= "" then
		vexalarm_profiles["profilelist"][key] = nil
		vexalarm_profiles[key] = nil
	end
	vexalarm_profiles_profile_delete = ""
end

function vexalarm_profile_load(fragment)
	local key = vexalarm_profiles_profile_load
	if key ~= "" then
		if vexalarm_profiles[key] ~= nil then 
			if fragment == "all" then
				vexalarm_profile_load("parameters")
				vexalarm_profile_load("spellprofiles")
				vexalarm_profile_load("spells")
				vexalarm_profiles_profile_load = ""
			elseif fragment == "parameters" then
				vexalarm_parameters = vexalarm_CopyTable(vexalarm_profiles[key]["vexalarm_parameters"])
			elseif fragment == "spellprofiles" then
				for k,v in pairs (vexalarm_CopyTable(vexalarm_profiles[key]["vexalarm_spellprofiles"])) do
					if k ~="profilelist" then
						vexalarm_spellprofiles["profilelist"][k] = k
						vexalarm_spellprofiles[k] = vexalarm_CopyTable(v)
					end
				end
			elseif fragment == "spells" then
				vexalarm_spells = vexalarm_CopyTable(vexalarm_profiles[key]["vexalarm_spells"])
			end
		end
	end
end







